==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/calendar/ui/CalendarPerspective.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.ui;

import org.eclipse.ui.IFolderLayout;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;

import com.clustercontrol.calendar.view.AddInfoListView;
import com.clustercontrol.calendar.view.CalendarListView;
import com.clustercontrol.calendar.view.WeekdayInfoListView;

/**
 * ѡڥƥ֥饹
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class CalendarPerspective implements IPerspectiveFactory {

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IPerspectiveFactory#createInitialLayout(org.eclipse.ui.IPageLayout)
     */
    public void createInitialLayout(IPageLayout layout) {
        //󥻥åȤɲ
        layout.addActionSet("com.clustercontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.collectiverun.ActionSet");
        layout.addActionSet("com.clustercontrol.jobmanagement.ActionSet");
        layout.addActionSet("com.clustercontrol.monitor.ActionSet");
        layout.addActionSet("com.clustercontrol.repository.ActionSet");
        layout.addActionSet("com.clustercontrol.performance.ActionSet");
        layout.addActionSet("com.clustercontrol.syslogng.ActionSet");
        layout.addActionSet("com.clustercontrol.accesscontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.process.ActionSet");
        layout.addActionSet("com.clustercontrol.sql.ActionSet");
        layout.addActionSet("com.clustercontrol.ping.ActionSet");
        layout.addActionSet("com.clustercontrol.hinemosagent.ActionSet");
        layout.addActionSet("com.clustercontrol.snmp.ActionSet");
        layout.addActionSet("com.clustercontrol.priority.ActionSet");
        layout.addActionSet("com.clustercontrol.http.ActionSet");
        layout.addActionSet("com.clustercontrol.troubledetection.ActionSet");
        layout.addActionSet("com.clustercontrol.snmptrap.ActionSet");
        
        //ǥΰɽˤ
        layout.setEditorAreaVisible(false);

        //ǥΰID
        String editorArea = layout.getEditorArea();
        //ǥΰξ60%ե
        IFolderLayout top = layout.createFolder("top", IPageLayout.TOP,
                (float) 0.6f, editorArea);
        //ǥΰβ40%եκ
        IFolderLayout bottom = layout.createFolder("bottom",
                IPageLayout.BOTTOM, (float) 0.4f, editorArea);
        //ID=bottomκ50%ե
        IFolderLayout bottomLeft = layout.createFolder("bottomLeft",
                IPageLayout.LEFT, (float) 0.5f, "bottom");

        top.addView(CalendarListView.ID);
        bottomLeft.addView(WeekdayInfoListView.ID);
        bottom.addView(AddInfoListView.ID);
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/calendar/ui/CalendarPerspective.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.calendar.ui;

import org.eclipse.ui.IFolderLayout;
import org.eclipse.ui.IPageLayout;
import org.eclipse.ui.IPerspectiveFactory;

import com.clustercontrol.calendar.view.AddInfoListView;
import com.clustercontrol.calendar.view.CalendarListView;
import com.clustercontrol.calendar.view.WeekdayInfoListView;

/**
 * カレンダパースペクティブクラス
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class CalendarPerspective implements IPerspectiveFactory {

    /*
     * (non-Javadoc)
     * 
     * @see org.eclipse.ui.IPerspectiveFactory#createInitialLayout(org.eclipse.ui.IPageLayout)
     */
    public void createInitialLayout(IPageLayout layout) {
        //アクションセットを追加
        layout.addActionSet("com.clustercontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.collectiverun.ActionSet");
        layout.addActionSet("com.clustercontrol.jobmanagement.ActionSet");
        layout.addActionSet("com.clustercontrol.monitor.ActionSet");
        layout.addActionSet("com.clustercontrol.repository.ActionSet");
        layout.addActionSet("com.clustercontrol.performance.ActionSet");
        layout.addActionSet("com.clustercontrol.syslogng.ActionSet");
        layout.addActionSet("com.clustercontrol.accesscontrol.ActionSet");
        layout.addActionSet("com.clustercontrol.process.ActionSet");
        layout.addActionSet("com.clustercontrol.sql.ActionSet");
        layout.addActionSet("com.clustercontrol.ping.ActionSet");
        layout.addActionSet("com.clustercontrol.hinemosagent.ActionSet");
        layout.addActionSet("com.clustercontrol.snmp.ActionSet");
        layout.addActionSet("com.clustercontrol.priority.ActionSet");
        layout.addActionSet("com.clustercontrol.http.ActionSet");
        layout.addActionSet("com.clustercontrol.troubledetection.ActionSet");
        layout.addActionSet("com.clustercontrol.snmptrap.ActionSet");
        
        //エディタ領域を非表示にする
        layout.setEditorAreaVisible(false);

        //エディタ領域のIDを取得
        String editorArea = layout.getEditorArea();
        //エディタ領域の上部60%を占めるフォルダを作成
        IFolderLayout top = layout.createFolder("top", IPageLayout.TOP,
                (float) 0.6f, editorArea);
        //エディタ領域の下部40%を占めるフォルダの作成
        IFolderLayout bottom = layout.createFolder("bottom",
                IPageLayout.BOTTOM, (float) 0.4f, editorArea);
        //ID=bottomの左50%を占めるフォルダを作成
        IFolderLayout bottomLeft = layout.createFolder("bottomLeft",
                IPageLayout.LEFT, (float) 0.5f, "bottom");

        top.addView(CalendarListView.ID);
        bottomLeft.addView(WeekdayInfoListView.ID);
        bottom.addView(AddInfoListView.ID);
    }
}
